@@ -293,7 +293,8 @@ class Parser(_ConfigurationData):
                 for k,v in self[section_name].iteritems():
                     print section_name+'.'+k+' = ' +v
 
-if __name__ == '__main__':
+def main():
+#if __name__ == '__main__':
     import sys
     if len(sys.argv) == 2 and sys.argv[1] in ['help', '--help', '-h']:
         print "Configuration parser - help"
@@ -303,7 +304,7 @@ if __name__ == '__main__':
         p = Parser(conf)
         p.print_all()
     elif len(sys.argv) < 3:
-        print "Usage:\n", sys.argv[0],"[path/name of an INI style config file] [section.variable to fetch|--print-all]"
+        print "Usage:\n", sys.argv[0],"[full path/only name of an INI style config file] [section.variable to fetch|--print-all]"
         sys.exit(1)
     else:
         try:
